==> fengoffice_1.7.5.zip: fengoffice/language/nb_no/project_interface.php <==
<?php return array(
	'upcoming milestones in next 30 days' => 'Kommende milepæler (i de neste 30 dager)',
	'show all upcoming milestones' => 'Vis alle kommende milepæler (totalt {0})',
	'recent activities' => 'Seneste aktiviteter',
	'search button caption' => 'Søk',
	'search result description' => 'Viser <strong>{0} av {1}</strong> objekter som passer <strong>\\"{2}"</strong>',
	'search result description short' => '{0} til {1} av {2}',
	'edit this file' => 'Rediger denne filen',
	'file contents' => 'Filinnhold',
	'revision comment' => 'Endringskommentar',
	'edit revision comment' => 'Rediger endringskommentar',
	'initial versions' => '-- Oppbrinnelig versjon --',
	'file details' => 'Fildetaljer',
	'view file details' => 'Vis fildetaljer',
	'add link object control' => 'Legg til objekt',
	'remove link object control' => 'Fjern',
	'select object' => 'Velg et objekt',
	'icalendar' => 'Kalender',
	'icalendar subscribe' => 'Kalender',
	'success message' => 'Suksessnotat',
	'project form action' => 'Handling',
	'project form action add comment' => 'Legg til kommentar',
	'project form action add task' => 'Legg til oppgave',
	'project form enabled' => 'Aktivert',
	'project form visible' => 'Synlig',
	'add comment to message' => 'Legg en kommentar til <a class="internalLink" href="{0}">{1}</a>',
	'add comment to message short' => 'til',
	'add task to list' => 'Legg en opgave til <a class="internalLink" href="{0}">{1}</a>',
	'add task to list short' => 'til',
	'select a tag' => 'Velg et stikkord...',
	'select a user' => 'Velg en bruker...',
	'select a project' => 'Velg et arbeidsområde...',
	'upload a file' => 'Last opp en fil',
	'uploading file' => 'Laster opp fil...',
	'cannot delete personal project' => 'Det personlige arbeidsområdet kan ikke slettes',
	'workspace color' => 'Arbeidsområdets farge',
	'workspace template' => 'Arbeidsområdets mal',
	'color1' => 'Rød',
	'color2' => 'Grønn',
	'color3' => 'Blå',
	'color4' => 'Gul',
	'color5' => 'Oransje',
	'color6' => 'Lys rød',
	'color7' => 'Lys blå',
	'color8' => 'Fiolett',
	'choose a color' => 'Velg en farge',
	'show more' => 'Vis mer',
	'show more amount' => 'Vis mer ({0})',
	'new contact' => 'Ny kontakt',
	'work' => 'Arbeid',
	'home' => 'Hjemme',
	'other' => 'Annet',
	'display' => 'Vis',
	'display options' => 'Visningsalternativer',
	'show in project' => 'Vis i arbeidsområde',
	'reporting' => 'Rapporter',
	'chart' => 'Graf',
	'new chart' => 'Ny graf',
	'add chart' => 'Legg til graf',
	'edit chart' => 'Rediger graf',
	'delete chart' => 'Slett graf',
	'bars chart' => 'Grafer',
	'pie chart' => 'Pie',
	'lines chart' => 'Linjer',
	'draw chart' => 'Tegning',
	'chart display' => 'Vis',
	'bar sketch' => 'Enkle grafer',
	'bar 3d' => '3d grafer',
	'bar glass' => 'Glassgrafer',
	'budgeted' => 'Budgeted',
	'current' => 'Nåværende',
	'executed' => 'Kjørt',
	'not executed' => 'Ikke kjørt',
	'success deleted chart' => 'Chart \'{0}\' deleted successfully',
	'task priority' => 'Prioritet',
	'high priority' => 'Høy',
	'normal priority' => 'Normal',
	'low priority' => 'Lav',
	'time estimate' => 'Tidsestimat',
	'x hours' => '{0} timer.',
	'pending' => 'Venter',
	'new task template' => 'Ny oppgavemal',
	'edit task template' => 'Rediger oppgavemal',
	'new task from template' => 'Ny oppgave fra mal',
	'save as template' => 'Lagre som mal',
	'save template' => 'Lagre mal',
	'delete template' => 'Slett mal',
	'new milestone template' => 'Ny milepælmal',
	'new milestone from template' => 'Ny milepæl fra mal',
	'loading' => 'Laster',
	'show all' => 'Vis alle',
	'unassigned' => 'Utildelt',
	'latest comments' => 'Seneste kommentarer',
	'copy of file' => 'Kopi av {0}',
	'remove this widget' => 'Fjern dette skjermelementet',
	'add a new' => 'Legg til en ny',
	'other settings' => 'Andre innstillinger',
	'incoming settings' => 'Innkommende innstillinger',
	'default account' => 'Standardkonto',
	'signature' => 'Signatur',
	'attach contents' => 'Legg ved innhold',
	'set parent task' => 'Velg overordnet oppgave',
	'field title' => 'Tittel',
	'field text' => 'Tekst',
	'field email' => 'E-post',
	'field from' => 'Fra',
	'field to' => 'Til',
	'field subject' => 'Emne',
	'field comment' => 'Kommentar',
	'field email2' => 'Andre e-post',
	'field body_plain' => 'Melding',
	'field from_name' => 'Fra',
	'field firstname' => 'Navn',
	'field lastname' => 'Etternavn',
	'field filecontent' => 'Innhold',
	'field uid' => 'Unik ID',
	'field h_address' => 'Hjemadresse',
	'field w_address' => 'Arbeidadresse',
	'field o_address' => 'Andre adresser',
	'create task from email' => 'Opprett en oppgave av denne e-posten',
	'create task from email description' => 'Fra:      {1}
Emne:   {0}

{2}',
	'suggested workspaces' => 'Suggested workspaces',
	'mail account sender name' => 'Sendernavn',
	'linked main title' => 'Lenker',
	'linked file tab' => 'Filer',
	'linked email tab' => 'E-post',
	'linked emailunclassified tab' => 'Uklassifisert e-post',
	'linked message tab' => 'Notater',
	'linked contact tab' => 'Kontakter',
	'linked comment tab' => 'Kommentarer',
	'linked webpage tab' => 'Vevlenker',
	'linked company tab' => 'Foretak',
	'linked milestone tab' => 'Milepæler',
	'linked task tab' => 'Oppgaver',
	'linked event tab' => 'Hendelser',
	'all permissions' => 'Alle',
	'project description' => 'Beskrivelse',
	'new file' => 'Ny fil',
	'download history' => 'Nedlastningshistorie',
	'downloaded by' => 'Lastet ned av',
	'downloaded on' => 'Lastet ned den',
	'order by filename' => 'filnavn (a-z)',
	'order by posttime' => 'dato og tid',
	'all files' => 'Alle filer',
	'enable comments' => 'Aktiver kommentarer',
	'enable anonymous comments' => 'Anonyme kommentarer',
	'completed task' => 'Fullført oppgave',
	'completed tasks' => 'Fullførte oppgaver',
	'open task' => 'Åpen oppgaven',
	'open tasks' => 'Åpne oppgavene',
	'recently completed tasks' => 'Seneste fullførte oppgaver',
	'read more' => 'Les mer »',
	'message separator' => '<p>* * *</p>',
	'companies involved in project' => 'Involverte foretak',
	'expand additional text' => 'Utvid',
	'collapse additional text' => 'Forminsk',
	'email notification' => 'E-postvarsel',
	'can manage messages' => 'Administrer notater',
	'can manage tasks' => 'Administrer oppgaver',
	'can manage milestones' => 'Administrer milepæler',
	'can upload files' => 'Oppdater filer',
	'can manage files' => 'Administrer filer',
	'can manage properties' => 'Administrer egenskaper',
	'can manage events' => 'Administrer hendelser',
	'add by' => 'lagt til av',
	'edit by' => 'oppdatert av',
	'delete by' => 'slettet av',
	'close by' => 'lukket av',
	'open by' => 'åpnet av',
	'upload by' => 'opplastet av',
	'created by' => 'Opprettet av',
	'project status' => 'Arbeidsområdestatus',
	'existing file' => 'Eksisterende fil',
	'file revision title short' => 'Opprettet den {0}</span>',
	'update file' => 'Oppdater fil',
	'last revision' => 'Siste endring',
	'show in parents' => 'Vis i underordnede',
	'mail account permissions' => 'Kontoinnstillinger',
	'cannot access account' => 'Ingen adgang',
	'can view account emails' => 'Kan lese/skrive e-post',
	'can view account emails and edit' => 'Kan lese/skrive e-post og redigere e-postkontoer',
	'personal settings' => 'Personlige innstillinger',
	'comments on message' => '{0} kommentar(er)',
	'comment on object' => 'Kommentar for \'{0}\' på \'{1}\'',
	'revisions on file' => '{0} revidering(er)',
	'milestone assigned to' => 'Tildelt {0}',
	'assigned to' => 'Tildelt',
	'project started on' => 'Startet',
	'email sent by linktitle' => 'Sendt av {1}, {0}',
	'number of tagged objects' => '{0} objekt(er)',
	'add custom property' => 'Legg til egendefinert egenskap',
	'fetch imap folders' => 'Hent IMAP-kataloger',
	'no reports found' => 'Ingen rapporter funnet for {0}',
	'classify mails on workspace' => 'Klassifiser automatisk til arbeidsområde',
	'apply assignee to subtasks' => 'Bruk tilordning på underoppgaver',
	'task open of total tasks' => '{0} åpen av {1} oppgaver i listen',
	'subtask of' => 'Underoppgave av: <a class="internalLink" href="{0}">{1}</a>',
	'message posted on by linktitle' => 'Postet på {0} av {1}',
	'comment posted on by linktitle' => 'Postet på {0} av {1}',
	'message posted on by' => 'Postet på {0} av <a class="internalLink" href="{1}">{2}</a>',
	'comment posted on' => 'Postet på {0}',
	'comment posted on by' => 'Postet på {0} av <a class="internalLink" href="{1}">{2}</a>',
	'view all completed tasks' => 'Alle fullførte oppgaver (totalt {0})',
	'completed on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'started on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'posted on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'send milestone assigned to notification' => 'Send e-postvarsel til brukeren',
	'send task assigned to notification' => 'Send e-postvarsel til brukeren',
	'edit company data' => '<a class="internalLink" href="{0}">Rediger</a> foretakdata',
	'tags used on projects' => 'Stikkord i bruk på arbeidsområdet',
	'download history for' => 'Nedlastningshistorie for <a class="internalLink" href="{0}">{1}</a>',
	'file revision info short' => 'Endring #{0} <span>(opprettet på {1})</span>',
	'file revision info long' => 'Endring #{0} <span>(av <a class="internalLink" href="{1}">{2}</a> på {3})</span>',
	'file revision title long' => '<b><a class="internalLink" href="{0}">{1}</a></b> på {2}',
	'file checkout info short' => '<span>Utsjekket på {0}</span>',
	'file checkout info long' => '<span>Utsjekket av </span> <a class="internalLink" href="{0}">{1}</a> <span> på {2}</span>',
	'default account description' => 'Standardkonto er kontoen som e-post sendes fra om annet ikke er valgt.',
	'signature description' => 'Signaturen vil bli lagt til i alle e-poster sendt fra kontoen.',
	'mail account sender name description' => 'Navn som skal vises i "Fra"-feltet på sendte e-poster. Dersom feltet er blankt vil brukerens navn bli brukt.',
	'classify mails on workspace desc' => 'Dersom valgt, vil all e-post sendt til eller fra denne kontoen klassifiseres til det valgte arbeidsområde.',
	'personal settings desc' => 'Dette er innstillinger som er brukerspesifikke, og som ikke har innflytelse på andre brukere som har tilgang til kontoen.',
	'company users involved in project' => '{0} brukere er invlovert i {1}',
	'upload project desc' => 'Arbeidsområdet hvor den opplastede filen skal lagres',
	'upload description desc' => 'Skriv inn en beskrivelse for filen',
	'show in project desc' => 'Vis denne grafen på oversiktspanelet for valgt arbeidsområde',
	'show in parents desc' => 'Vis denne grafen på oversiktspanelet for alle over/underordnende arbeidsområder for det valgte arbeidsområde',
	'time estimate desc' => 'Estimert tid for oppgaven i timer.',
	'include unworked pending tasks' => 'Inkluder ventende oppgaver som ikke er arbeidet på',
	'unworked pending tasks' => 'Ventende oppgaver som ikke er arbeidet på',
	'TasksByDueDate' => 'Personlige oppgaver sortert etter forfallsdato',
	'error deleted chart' => 'En feil oppsto under slettingen av grafen',
	'cannot change parent workspace description' => 'Dette arbeidsområdet kan være et underområde til et område du ikke har tilgang til.',
	'update unset billing values' => 'Oppdater tidsrom med tømte betalingsverdier',
	'upload and link' => 'Last opp en ny fil og legg den til objektet',
	'can assign to owners' => 'Tildel medlemmer av foretaket arbeidsoppgaver',
	'can assign to other' => 'Tildel medlemmer av andre klienter arbeidsoppgaver',
	'show project desciption in overview' => 'Vise beskrivelse på arbeidsområdets oversiktsside?',
	'link existing object' => 'Lenk eksisterende objekt (fra dokument-seksjonen)',
	'urgent priority' => 'Haster',
	'attachment from email' => 'Veldagt i e-posten "{0}"',
	'BudgetExecution' => 'Kjør budsjett',
	'BudgetExecutionTrack' => 'Kjør budsjett etter måned',
	'MonthlyBudgetExecution' => 'Kjør budsjett etter nåværende måned',
	'assign milestone task list desc' => 'Oppgaven ble tilordnet en eksisterende milepæl',
	'version file change' => 'Husk denne endringen (kun den gamle filen blir lagret for framtidig referansen)',
	'ObjectTypeCount' => 'Objektantall etter type',
	'private message desc' => 'Private notat er kun synlige til eierforetakets medlemmer. Medlemmer av klientforetak vil ikke kunne se dem.',
	'private webpage desc' => 'Private vevlenker er kun synlige til eierforetakets medlemmer. Medlemmer av klientforetak vil ikke kunne se dem.',
	'private milestone desc' => 'Private milepæler er kun synlige til eierforetakets medlemmer. Medlemmer av klientforetak vil ikke kunne se dem.',
	'private task list desc' => 'Private oppgaver er kun synlige til eierforetakets medlemmer. Medlemmer av klientforetak vil ikke kunne se dem.',
	'private comment desc' => 'Private kommentarer er kun synlige til eierforetakets medlemmer. Medlemmer av klientforetak vil ikke kunne se dem.',
	'private file desc' => 'Private filer er kun synlige til eierforetakets medlemmer. Medlemmer av klientforetak vil ikke kunne se dem.',
	'total objects tagged with' => 'Det fins <b>{0}</b> objekter merket med <b>{1}</b> stikkord på dette arbeidsområdet',
	'no objects tagged with' => 'Det fins ingen objekter på arbeidsområdet markert med <b>{0}</b>',
	'tags widget description' => 'Liste med kommaseparerte stikkord (for eksempel: "grensesnitt, javascript, offentlig beta")',
	'email notification desc' => 'Motta varsel, og abonner valgte brukere på dette notatet via e-post',
	'important message desc' => 'Viktige notater er listet i "Viktige notater" modulen på arbeidsområdets notat side',
	'important file desc' => 'Viktige filer er listet i "Viktige filer" modulen i dokumentseksjonen',
	'project permissions form hint' => 'Bruk av <a class="internalLink" href="{0}">rettighetsskjemaet/a> lar deg enkelt legge til og fjerne foretak og brukere, og kontrollere deres rettigheter.',
	'upload file desc' => 'Du kan laste opp filer av alle filtyper. Den maksimale filstørrelsen er {0}',
	'icalendar subscribe desc' => 'Bruk denne lenken for å importere milepældata til din favorittkalender.',
	'enable comments desc' => 'Brukere som kan se dette objektet kan kommentere det. Velg "Nei" for å deaktivere kommentarer',
	'subscribers desc' => 'Abonnementer vil motta e-postvarsel når noen kommenterer dette objektet',
	'replace file description' => 'Du kan overskrive eksisterende fil ved å spesifisere en ny. Dersom du ikke vil overskrive den lar du feltet være blankt.',
	'icalendar password change notice' => '<strong>Husk:</strong> dersom du vil endre passordet ditt, vil også kalenderlenken bli endret! Da må du oppdatere abonnementet ditt.',
	'cannot change parent workspace' => 'Du har ikke rettigheter til å endre arbeidsområdets overordnede område.',
	'add subscribers desc' => 'Abonner valgte brukere til objektet. Abonnerende brukere vil motta varsel om endringer på objektet.',
	'update unset billing values desc' => 'HUSK: Denne handlingen vil legge til nye betalingsverdier for alle timeoppføringer uten verdier. Er du sikker på at du ønsker å fortsette?',
	'upload tag desc' => 'Her kan du velge et eksisterende stikkord eller legge til et nytt for filen. Etter at du har valgt stikkord, trykk Inn for å legge til en til.',
	'upload permissions desc' => 'Velg brukerne som skal ha tilgang til filen. Velg brukernavn som skal legges til, trykk Inn for å legge til en bruker til.',
	'assign contact to workspace desc' => 'For å tilordne kontakter til et arbeidsområde kontroller arbeidsområdet og fyll inn rollen i tekstfeltet.',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/nb_no/project_interface.php <==
<?php return array(
	'upcoming milestones in next 30 days' => 'Kommende milepæler (i de neste 30 dager)',
	'show all upcoming milestones' => 'Vis alle kommende milepæler (totalt {0})',
	'recent activities' => 'Seneste aktiviteter',
	'search button caption' => 'Søk',
	'search result description' => 'Viser <strong>{0} av {1}</strong> objekter som passer <strong>\\"{2}"</strong>',
	'search result description short' => '{0} til {1} av {2}',
	'edit this file' => 'Rediger denne filen',
	'file contents' => 'Filinnhold',
	'revision comment' => 'Endringskommentar',
	'edit revision comment' => 'Rediger endringskommentarq',
	'initial versions' => '-- Oppbrinnelig versjon --',
	'file details' => 'Fildetaljer',
	'view file details' => 'Vis fildetaljer',
	'add link object control' => 'Legg til objekt',
	'remove link object control' => 'Fjern',
	'select object' => 'Velg et objekt',
	'icalendar' => 'Kalender',
	'icalendar subscribe' => 'Kalender',
	'success message' => 'Suksessnotat',
	'project form action' => 'Handling',
	'project form action add comment' => 'Legg til kommentar',
	'project form action add task' => 'Legg til oppgave',
	'project form enabled' => 'Aktivert',
	'project form visible' => 'Synlig',
	'add comment to message' => 'Legg en kommentar til <a class="internalLink" href="{0}">{1}</a>',
	'add comment to message short' => 'til',
	'add task to list' => 'Legg en opgave til <a class="internalLink" href="{0}">{1}</a>',
	'add task to list short' => 'til',
	'select a tag' => 'Velg et stikkord...',
	'select a user' => 'Velg en bruker...',
	'select a project' => 'Velg et arbeidsområde...',
	'upload a file' => 'Last opp en fil',
	'uploading file' => 'Laster opp fil...',
	'cannot delete personal project' => 'Det personlige arbeidsområdet kan ikke slettes',
	'workspace color' => 'Arbeidsområdets farge',
	'workspace template' => 'Arbeidsområdets mal',
	'color1' => 'Rød',
	'color2' => 'Grønn',
	'color3' => 'Blå',
	'color4' => 'Gul',
	'color5' => 'Oransje',
	'color6' => 'Lys rød',
	'color7' => 'Lys blå',
	'color8' => 'Fiolett',
	'choose a color' => 'Velg en farge',
	'show more' => 'Vis mer',
	'show more amount' => 'Vis mer ({0})',
	'new contact' => 'Ny kontakt',
	'work' => 'Arbeid',
	'home' => 'Hjemme',
	'other' => 'Annet',
	'display' => 'Vis',
	'display options' => 'Visningsalternativer',
	'show in project' => 'Vis i arbeidsområde',
	'reporting' => 'Rapporter',
	'chart' => 'Graf',
	'new chart' => 'Ny graf',
	'add chart' => 'Legg til graf',
	'edit chart' => 'Rediger graf',
	'delete chart' => 'Slett graf',
	'bars chart' => 'Grafer',
	'pie chart' => 'Pie',
	'lines chart' => 'Linjer',
	'draw chart' => 'Tegning',
	'chart display' => 'Vis',
	'bar sketch' => 'Enkle grafer',
	'bar 3d' => '3d grafer',
	'bar glass' => 'Glassgrafer',
	'budgeted' => 'Budgeted',
	'current' => 'Nåværende',
	'executed' => 'Kjørt',
	'not executed' => 'Ikke kjørt',
	'success deleted chart' => 'Chart \'{0}\' deleted successfully',
	'task priority' => 'Prioritet',
	'high priority' => 'Høy',
	'normal priority' => 'Normal',
	'low priority' => 'Lav',
	'time estimate' => 'Tidsestimat',
	'x hours' => '{0} timer.',
	'pending' => 'Venter',
	'new task template' => 'Ny oppgavemal',
	'edit task template' => 'Rediger oppgavemal',
	'new task from template' => 'Ny oppgave fra mal',
	'save as template' => 'Lagre som mal',
	'save template' => 'Lagre mal',
	'delete template' => 'Slett mal',
	'new milestone template' => 'Ny milepælmal',
	'new milestone from template' => 'Ny milepæl fra mal',
	'loading' => 'Laster',
	'show all' => 'Vis alle',
	'unassigned' => 'Utildelt',
	'latest comments' => 'Seneste kommentarer',
	'copy of file' => 'Kopi av {0}',
	'remove this widget' => 'Fjern dette skjermelementet',
	'add a new' => 'Legg til en ny',
	'other settings' => 'Andre innstillinger',
	'incoming settings' => 'Innkommende innstillinger',
	'default account' => 'Standardkonto',
	'signature' => 'Signatur',
	'attach contents' => 'Legg ved innhold',
	'set parent task' => 'Velg overordnet oppgave',
	'field title' => 'Tittel',
	'field text' => 'Tekst',
	'field email' => 'E-post',
	'field from' => 'Fra',
	'field to' => 'Til',
	'field subject' => 'Emne',
	'field comment' => 'Kommentar',
	'field email2' => 'Andre e-post',
	'field body_plain' => 'Melding',
	'field from_name' => 'Fra',
	'field firstname' => 'Navn',
	'field lastname' => 'Etternavn',
	'field filecontent' => 'Innhold',
	'field uid' => 'Unik ID',
	'field h_address' => 'Hjemadresse',
	'field w_address' => 'Arbeidadresse',
	'field o_address' => 'Andre adresser',
	'create task from email' => 'Opprett en oppgave av denne e-posten',
	'create task from email description' => 'Fra:      {1}
Emne:   {0}

{2}',
	'suggested workspaces' => 'Suggested workspaces',
	'mail account sender name' => 'Sendernavn',
	'linked main title' => 'Lenker',
	'linked file tab' => 'Filer',
	'linked email tab' => 'E-post',
	'linked emailunclassified tab' => 'Uklassifisert e-post',
	'linked message tab' => 'Notater',
	'linked contact tab' => 'Kontakter',
	'linked comment tab' => 'Kommentarer',
	'linked webpage tab' => 'Vevlenker',
	'linked company tab' => 'Foretak',
	'linked milestone tab' => 'Milepæler',
	'linked task tab' => 'Oppgaver',
	'linked event tab' => 'Hendelser',
	'all permissions' => 'Alle',
	'project description' => 'Beskrivelse',
	'new file' => 'Ny fil',
	'download history' => 'Nedlastningshistorie',
	'downloaded by' => 'Lastet ned av',
	'downloaded on' => 'Lastet ned den',
	'order by filename' => 'filnavn (a-z)',
	'order by posttime' => 'dato og tid',
	'all files' => 'Alle filer',
	'enable comments' => 'Aktiver kommentarer',
	'enable anonymous comments' => 'Anonyme kommentarer',
	'completed task' => 'Fullført oppgave',
	'completed tasks' => 'Fullførte oppgaver',
	'open task' => 'Åpen oppgaven',
	'open tasks' => 'Åpne oppgavene',
	'recently completed tasks' => 'Seneste fullførte oppgaver',
	'read more' => 'Les mer »',
	'message separator' => '<p>* * *</p>',
	'companies involved in project' => 'Involverte foretak',
	'expand additional text' => 'Utvid',
	'collapse additional text' => 'Forminsk',
	'email notification' => 'E-postvarsel',
	'can manage messages' => 'Administrer notater',
	'can manage tasks' => 'Administrer oppgaver',
	'can manage milestones' => 'Administrer milepæler',
	'can upload files' => 'Oppdater filer',
	'can manage files' => 'Administrer filer',
	'can manage properties' => 'Administrer egenskaper',
	'can manage events' => 'Administrer hendelser',
	'add by' => 'lagt til av',
	'edit by' => 'oppdatert av',
	'delete by' => 'slettet av',
	'close by' => 'lukket av',
	'open by' => 'åpnet av',
	'upload by' => 'opplastet av',
	'created by' => 'Opprettet av',
	'project status' => 'Arbeidsområdestatus',
	'existing file' => 'Eksisterende fil',
	'file revision title short' => 'Opprettet den {0}</span>',
	'update file' => 'Oppdater fil',
	'last revision' => 'Siste endring',
	'show in parents' => 'Vis i underordnede',
	'mail account permissions' => 'Kontoinnstillinger',
	'cannot access account' => 'Ingen adgang',
	'can view account emails' => 'Kan lese/skrive e-post',
	'can view account emails and edit' => 'Kan lese/skrive e-post og redigere e-postkontoer',
	'personal settings' => 'Personlige innstillinger',
	'comments on message' => '{0} kommentar(er)',
	'comment on object' => 'Kommentar for \'{0}\' på \'{1}\'',
	'revisions on file' => '{0} revidering(er)',
	'milestone assigned to' => 'Tildelt {0}',
	'assigned to' => 'Tildelt',
	'project started on' => 'Startet',
	'email sent by linktitle' => 'Sendt av {1}, {0}',
	'number of tagged objects' => '{0} objekt(er)',
	'add custom property' => 'Legg til egendefinert egenskap',
	'fetch imap folders' => 'Hent IMAP-kataloger',
	'no reports found' => 'Ingen rapporter funnet for {0}',
	'classify mails on workspace' => 'Klassifiser automatisk til arbeidsområde',
	'apply assignee to subtasks' => 'Bruk tilordning på underoppgaver',
	'task open of total tasks' => '{0} åpen av {1} oppgaver i listen',
	'subtask of' => 'Underoppgave av: <a class="internalLink" href="{0}">{1}</a>',
	'message posted on by linktitle' => 'Postet på {0} av {1}',
	'comment posted on by linktitle' => 'Postet på {0} av {1}',
	'message posted on by' => 'Postet på {0} av <a class="internalLink" href="{1}">{2}</a>',
	'comment posted on' => 'Postet på {0}',
	'comment posted on by' => 'Postet på {0} av <a class="internalLink" href="{1}">{2}</a>',
	'view all completed tasks' => 'Alle fullførte oppgaver (totalt {0})',
	'completed on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'started on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'posted on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'send milestone assigned to notification' => 'Send e-postvarsel til brukeren',
	'send task assigned to notification' => 'Send e-postvarsel til brukeren',
	'edit company data' => '<a class="internalLink" href="{0}">Rediger</a> foretakdata',
	'tags used on projects' => 'Stikkord i bruk på arbeidsområdet',
	'download history for' => 'Nedlastningshistorie for <a class="internalLink" href="{0}">{1}</a>',
	'file revision info short' => 'Endring #{0} <span>(opprettet på {1})</span>',
	'file revision info long' => 'Endring #{0} <span>(av <a class="internalLink" href="{1}">{2}</a> på {3})</span>',
	'file revision title long' => '<b><a class="internalLink" href="{0}">{1}</a></b> på {2}',
	'file checkout info short' => '<span>Utsjekket på {0}</span>',
	'file checkout info long' => '<span>Utsjekket av </span> <a class="internalLink" href="{0}">{1}</a> <span> på {2}</span>',
	'default account description' => 'Standardkonto er kontoen som e-post sendes fra om annet ikke er valgt.',
	'signature description' => 'Signaturen vil bli lagt til i alle e-poster sendt fra kontoen.',
	'mail account sender name description' => 'Navn som skal vises i "Fra"-feltet på sendte e-poster. Dersom feltet er blankt vil brukerens navn bli brukt.',
	'classify mails on workspace desc' => 'Dersom valgt, vil all e-post sendt til eller fra denne kontoen klassifiseres til det valgte arbeidsområde.',
	'personal settings desc' => 'Dette er innstillinger som er brukerspesifikke, og som ikke har innflytelse på andre brukere som har tilgang til kontoen.',
	'company users involved in project' => '{0} brukere er invlovert i {1}',
	'upload project desc' => 'Arbeidsområdet hvor den opplastede filen skal lagres',
	'upload description desc' => 'Skriv inn en beskrivelse for filen',
	'show in project desc' => 'Vis denne grafen på oversiktspanelet for valgt arbeidsområde',
	'show in parents desc' => 'Vis denne grafen på oversiktspanelet for alle over/underordnende arbeidsområder for det valgte arbeidsområde',
	'time estimate desc' => 'Estimert tid for oppgaven i timer.',
	'include unworked pending tasks' => 'Inkluder ventende oppgaver som ikke er arbeidet på',
	'unworked pending tasks' => 'Ventende oppgaver som ikke er arbeidet på',
	'TasksByDueDate' => 'Personlige oppgaver sortert etter forfallsdato',
	'error deleted chart' => 'En feil oppsto under slettingen av grafen',
	'cannot change parent workspace description' => 'Dette arbeidsområdet kan være et underområde til et område du ikke har tilgang til.',
	'update unset billing values' => 'Oppdater tidsrom med tømte betalingsverdier',
	'upload and link' => 'Last opp en ny fil og legg den til objektet',
	'can assign to owners' => 'Tildel medlemmer av foretaket arbeidsoppgaver',
	'can assign to other' => 'Tildel medlemmer av andre klienter arbeidsoppgaver',
	'show project desciption in overview' => 'Vise beskrivelse på arbeidsområdets oversiktsside?',
	'link existing object' => 'Lenk eksisterende objekt (fra dokument-seksjonen)',
); ?>
